#ifndef UNIT_DEFINITIONS_H
#define UNIT_DEFINITIONS_H 1

#include "unitylib.h"

struct unit_definition_syntax {
    const char* syntax_name;    /* the name of the syntax being described (eg "fits") */
    char may_have_si_prefixes;
    char is_deprecated;
    const char* preferred_abbrev; /* such as 'm' for metre */
};
typedef struct unit_definition_syntax UnitDefSyntax;

struct unit_definition {
    const char* abbrev; /* the name of one of the abbrevs for this unit */
    const char* name;   /* the name of the unit, such as 'metre' -- not the abbreviation 'm' */
    const char* type;   /* type such as 'length' */
    const char* notes;  /* for example 'Hz = s-1', NULL if no notes present */
    const char* latex_form;     /* an abbrev suitable for LaTeX, if different from a preferred syntax */
    /* There is a unit_definition element for each syntax, whether or
       not the unit is recognised.  If a syntax does not recognise a
       unit, this is indicated by setting syntax_name to NULL. */
    struct unit_definition_syntax syntaxes[U_NSYNTAXES];
};
typedef struct unit_definition UnitDef;

const UnitDef* unity_get_unit(const char* abbrev);

#define UNITY_CHECK_RECOGNISED 1
#define UNITY_CHECK_RECOMMENDED 2
#define UNITY_CHECK_CONSTRAINTS 4
#define UNITY_CHECK_ALL UNITY_CHECK_RECOGNISED | UNITY_CHECK_RECOMMENDED | UNITY_CHECK_CONSTRAINTS
int unity_check_unit(const Unit* u, const int syntax, const int flags);

int unity_check_expression(const UnitExpression* ue, const int syntax, const int flags);

#endif /* UNIT_DEFINITIONS_H */
