#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "unity.h"

int print_lexemes(char* s, FILE* out); /* from lex.lex */

static char* progname;

int yydebug;                    /* defined by bison */

void Usage(int status) 
{
    fprintf(stderr, "%s\n\nUsage: %s [-lgv] [-i isyntax] [-o osyntax] string\n       %s -S\n\
\n\
Options:\n\
    -i isyntax : set the input syntax -- for syntaxes see -S\n\
    -o osyntax : set the output syntax -- for syntaxes see -S\n\
    -v         : display validation checks\n\
    -l         : show the lexemes in the input (really only for debugging)\n\
    -g         : turn on debugging\n\
    -S         : show the list of parsers and formatters (and exit)\n",
            unity_version_string(), progname, progname);
    //fprintf(stderr, "num=%d\n", unity_version_number());
    exit(status);
}

int main(int argc, char** argv)
{
    char* unit_string = NULL;
    char ch;
    int show_lexemes = 0;
    int validate = 0;
    const char *input_syntax = "fits";
    const char *output_syntax = "debug";
    
    progname = argv[0];

    while ((ch = getopt(argc, argv, "ghi:lo:Sv")) != -1) {
        switch (ch) {
          case 'g':
            yydebug = 1;
            break;
          case 'l':
            show_lexemes = 1;
            break;
          case 'h':             /* help */
            Usage(0);
            break;
          case 'i':             /* input syntax */
            input_syntax = optarg;
            break;
          case 'o':             /* output syntax */
            output_syntax = optarg;
            break;
          case 'v':             /* validate parsed expression */
            validate = 1;
            break;
          case 'S':
            {
                const char** syntaxes = unity_parser_names();
                int i;
                char* spacer = "parsers:    ";        
                for (i=0; syntaxes[i] != NULL; i++) {
                    printf("%s%s", spacer, syntaxes[i]);
                    spacer = ", ";
                }
                syntaxes = unity_formatter_names();
                spacer = "\nformatters: ";
                for (i=0; syntaxes[i] != NULL; i++) {
                    printf("%s%s", spacer, syntaxes[i]);
                    spacer = ", ";
                }
                putchar('\n');
                exit(0);        /* EXIT */
                break;
            }
          default:
            Usage(1);
            break;
        }
    }
    argc -= optind;
    argv += optind;
    unit_string = *argv;

    if (unit_string == NULL) {
        Usage(1);               /* ...and EXIT */
    }
    
    if (show_lexemes) {
        print_lexemes(unit_string, stdout);
    } else {
        const UnitExpression* parsed;
        int syntax_id;

        if ((syntax_id = unity_identify_parser(input_syntax)) < 0) {
            fprintf(stderr, "error: unidentified syntax \"%s\"\n", input_syntax);
        } else if ((parsed = unity_parse_string(unit_string, syntax_id)) == NULL) {
            // parse error
            fprintf(stderr, "parse error: %s\n", unity_parse_error());
        } else {
            char buf[1024];
            printf("%s\n", unity_write_formatted(buf, 1024, parsed, output_syntax));
            if (validate) {
                printf("check: all units recognised?           %s\n",
                       unity_check_expression(parsed, syntax_id, UNITY_CHECK_RECOGNISED) ? "yes" : "no");
                printf("check: all units recommended?          %s\n",
                       unity_check_expression(parsed, syntax_id, UNITY_CHECK_RECOMMENDED) ? "yes" : "no");
                printf("check: all units satisfy constraints?  %s\n",
                       unity_check_expression(parsed, syntax_id, UNITY_CHECK_CONSTRAINTS) ? "yes" : "no");
            }
        }
    }
    
    return 0;
}
