#include <stdio.h>
#if U_NSYNTAXES != 3
#  error "Mismatch in U_NSYNTAXES between ParseUnits and header"
#endif
static struct unit_definition unit_defs[] = {
    { "%", "percent", "unitless", NULL, "\\%", {
        { NULL, 0, 0, NULL },
        { NULL, 0, 0, NULL },
        { "cds", 0, 0, "%" },} },
    { "A", "ampere", "electric current", NULL, NULL, {
        { "fits", 1, 0, "A" },
        { "ogip", 1, 0, "A" },
        { "cds", 1, 0, "A" },} },
    { "AU", "astronomical unit", "length", "1.49598e11 m", NULL, {
        { "fits", 0, 0, "AU" },
        { "ogip", 0, 0, "AU" },
        { "cds", 0, 0, "AU" },} },
    { "Angstrom", "angstrom", "length", "1e-10 m", "\\angstrom", {
        { "fits", 0, 1, "Angstrom" },
        { "ogip", 0, 0, "Angstrom" },
        { NULL, 0, 0, NULL },} },
    { "C", "coulomb", "electric charge", "A s", NULL, {
        { "fits", 1, 0, "C" },
        { "ogip", 1, 0, "C" },
        { "cds", 1, 0, "C" },} },
    { "Crab", "crab", "flux density", "see OGIP standard, which permits only m prefix", NULL, {
        { NULL, 0, 0, NULL },
        { "ogip", 1, 0, "Crab" },
        { NULL, 0, 0, NULL },} },
    { "D", "debye", "miscellaneous units", "1/3 1e-29 C m", NULL, {
        { "fits", 0, 0, "D" },
        { NULL, 0, 0, NULL },
        { "cds", 0, 0, "D" },} },
    { "F", "farad", "electric capacitance", "C V-1", NULL, {
        { "fits", 1, 0, "F" },
        { "ogip", 1, 0, "F" },
        { "cds", 1, 0, "F" },} },
    { "G", "gauss", "magnetic field", "1e-4 T", NULL, {
        { "fits", 1, 1, "G" },
        { "ogip", 0, 0, "G" },
        { NULL, 0, 0, NULL },} },
    { "H", "henry", "inductance", "Wb A-1", NULL, {
        { "fits", 1, 0, "H" },
        { "ogip", 1, 0, "H" },
        { "cds", 1, 0, "H" },} },
    { "Hz", "hertz", "frequency", "s-1", NULL, {
        { "fits", 1, 0, "Hz" },
        { "ogip", 1, 0, "Hz" },
        { "cds", 1, 0, "Hz" },} },
    { "J", "joule", "energy", "N m", NULL, {
        { "fits", 1, 0, "J" },
        { "ogip", 1, 0, "J" },
        { "cds", 1, 0, "J" },} },
    { "Jy", "jansky", "flux density", "1e-26 W m-2 Hz-1", NULL, {
        { "fits", 1, 0, "Jy" },
        { "ogip", 1, 0, "Jy" },
        { "cds", 1, 0, "Jy" },} },
    { "K", "kelvin", "temperature", NULL, NULL, {
        { "fits", 1, 0, "K" },
        { "ogip", 1, 0, "K" },
        { "cds", 1, 0, "K" },} },
    { "N", "newton", "force", "kg m s-2", NULL, {
        { "fits", 1, 0, "N" },
        { "ogip", 1, 0, "N" },
        { "cds", 1, 0, "N" },} },
    { "Ohm", "ohm", "electric resistance", "V A-1", "\\ohm", {
        { "fits", 1, 0, "Ohm" },
        { "ogip", 1, 0, "ohm" },
        { "cds", 1, 0, "Ohm" },} },
    { "Pa", "pascal", "pressure, stress", "N m-2", NULL, {
        { "fits", 1, 0, "Pa" },
        { "ogip", 1, 0, "Pa" },
        { "cds", 1, 0, "Pa" },} },
    { "R", "rayleigh", "flux density", "1e10/(4PI) photons m-2 s-2 sr-1", NULL, {
        { "fits", 1, 0, "R" },
        { NULL, 0, 0, NULL },
        { NULL, 0, 0, NULL },} },
    { "Ry", "rydberg", "energy", "13.605692 eV", NULL, {
        { "fits", 0, 0, "Ry" },
        { NULL, 0, 0, NULL },
        { "cds", 1, 0, "Ry" },} },
    { "S", "siemens", "electric conductance", "A V-1", NULL, {
        { "fits", 1, 0, "S" },
        { "ogip", 1, 0, "S" },
        { "cds", 1, 0, "S" },} },
    { "Sun", "relative to sun", "miscellaneous units", "eg abundances", "\\odot", {
        { "fits", 0, 0, "Sun" },
        { NULL, 0, 0, NULL },
        { "cds", 0, 0, "Sun" },} },
    { "T", "tesla", "magnetic flux density", "Wb m-2", NULL, {
        { "fits", 1, 0, "T" },
        { "ogip", 1, 0, "T" },
        { "cds", 1, 0, "T" },} },
    { "V", "volt", "electrical potential", "J C-1", NULL, {
        { "fits", 1, 0, "V" },
        { "ogip", 1, 0, "V" },
        { "cds", 1, 0, "V" },} },
    { "W", "watt", "power", "J s-1", NULL, {
        { "fits", 1, 0, "W" },
        { "ogip", 1, 0, "W" },
        { "cds", 1, 0, "W" },} },
    { "Wb", "weber", "magnetic flux", "V s", NULL, {
        { "fits", 1, 0, "Wb" },
        { "ogip", 1, 0, "Wb" },
        { "cds", 1, 0, "Wb" },} },
    { "a", "year (Julian)", "time", "31 557 600s (365.25d), peta a (Pa) forbidden", NULL, {
        { "fits", 1, 0, "yr" },
        { "ogip", 0, 0, "yr" },
        { "cds", 1, 0, "yr" },} },
    { "adu", "Analog-to-digital converter", "miscellaneous units", NULL, NULL, {
        { "fits", 0, 0, "adu" },
        { NULL, 0, 0, NULL },
        { NULL, 0, 0, NULL },} },
    { "arcmin", "minute of arc", "plane angle", "1/60 deg", NULL, {
        { "fits", 0, 0, "arcmin" },
        { "ogip", 0, 0, "arcmin" },
        { "cds", 0, 0, "arcmin" },} },
    { "arcsec", "second of arc", "plane angle", "1/3600 deg", NULL, {
        { "fits", 0, 0, "arcsec" },
        { "ogip", 0, 0, "arcsec" },
        { "cds", 1, 0, "arcsec" },} },
    { "barn", "barn", "area", "1e-28 m2", NULL, {
        { "fits", 1, 1, "barn" },
        { "ogip", 0, 0, "barn" },
        { "cds", 1, 0, "barn" },} },
    { "beam", "beam area of observation", "miscellaneous units", "as in Jy/beam", NULL, {
        { "fits", 0, 0, "beam" },
        { NULL, 0, 0, NULL },
        { NULL, 0, 0, NULL },} },
    { "bin", "numerous applications", "miscellaneous units", "(including the 1-d analogue of pixel)", NULL, {
        { "fits", 0, 0, "bin" },
        { "ogip", 0, 0, "bin" },
        { NULL, 0, 0, NULL },} },
    { "bit", "binary information unit", "miscellaneous units", NULL, NULL, {
        { "fits", 1, 0, "bit" },
        { NULL, 0, 0, NULL },
        { "cds", 1, 0, "bit" },} },
    { "byte", "(computer) byte", "miscellaneous units", "8 bit", NULL, {
        { "fits", 1, 0, "byte" },
        { "ogip", 0, 0, "byte" },
        { "cds", 1, 0, "byte" },} },
    { "cd", "candela", "luminous intensity", NULL, NULL, {
        { "fits", 1, 0, "cd" },
        { "ogip", 1, 0, "cd" },
        { "cds", 1, 0, "cd" },} },
    { "chan", "(detector) channel", "miscellaneous units", NULL, NULL, {
        { "fits", 0, 0, "chan" },
        { "ogip", 0, 0, "chan" },
        { NULL, 0, 0, NULL },} },
    { "count", "count", "events", NULL, NULL, {
        { "fits", 0, 0, "count" },
        { "ogip", 0, 0, "count" },
        { "cds", 0, 0, "ct" },} },
    { "ct", "count", "events", NULL, NULL, {
        { "fits", 0, 0, "count" },
        { "ogip", 0, 0, "count" },
        { "cds", 0, 0, "ct" },} },
    { "d", "day", "time", "86000s", NULL, {
        { "fits", 0, 0, "d" },
        { "ogip", 0, 0, "d" },
        { "cds", 0, 0, "d" },} },
    { "deg", "degree of arc", "plane angle", "PI/180 rad", NULL, {
        { "fits", 0, 0, "deg" },
        { "ogip", 0, 0, "deg" },
        { "cds", 0, 0, "deg" },} },
    { "eV", "electron volt", "energy", "1.6021765e-19J", NULL, {
        { "fits", 1, 0, "eV" },
        { "ogip", 1, 0, "eV" },
        { "cds", 1, 0, "eV" },} },
    { "erg", "erg", "energy", "1e-7J", NULL, {
        { "fits", 0, 1, "erg" },
        { "ogip", 0, 0, "erg" },
        { NULL, 0, 0, NULL },} },
    { "g", "gramme", "mass", NULL, NULL, {
        { "fits", 1, 0, "g" },
        { "ogip", 1, 0, "g" },
        { "cds", 1, 0, "g" },} },
    { "h", "hour", "time", "60min = 3600s", NULL, {
        { "fits", 0, 0, "h" },
        { "ogip", 0, 0, "h" },
        { "cds", 0, 0, "h" },} },
    { "lm", "lumen", "luminous flux", "cd sr", NULL, {
        { "fits", 1, 0, "lm" },
        { "ogip", 1, 0, "lm" },
        { "cds", 1, 0, "lm" },} },
    { "lx", "lux", "illuminance", "lm m-2", NULL, {
        { "fits", 1, 0, "lx" },
        { "ogip", 1, 0, "lx" },
        { "cds", 1, 0, "lx" },} },
    { "lyr", "light year", "length", "9.460730e15 m", NULL, {
        { "fits", 0, 0, "lyr" },
        { "ogip", 0, 0, "lyr" },
        { NULL, 0, 0, NULL },} },
    { "m", "metre", "length", NULL, NULL, {
        { "fits", 1, 0, "m" },
        { "ogip", 1, 0, "m" },
        { "cds", 1, 0, "m" },} },
    { "mag", "(stellar) magnitude", "flux density", NULL, NULL, {
        { "fits", 1, 0, "mag" },
        { "ogip", 0, 0, "mag" },
        { "cds", 1, 0, "mag" },} },
    { "mas", "millisecond of arc", "plane angle", "1/3600000 deg", NULL, {
        { "fits", 0, 0, "mas" },
        { NULL, 0, 0, NULL },
        { "cds", 0, 0, "mas" },} },
    { "min", "minute", "time", "60s", NULL, {
        { "fits", 0, 0, "min" },
        { "ogip", 0, 0, "min" },
        { "cds", 0, 0, "min" },} },
    { "mol", "mole", "amount of substance", NULL, NULL, {
        { "fits", 1, 0, "mol" },
        { "ogip", 1, 0, "mol" },
        { "cds", 1, 0, "mol" },} },
    { "ohm", "ohm", "electric resistance", "V A-1", "\\ohm", {
        { "fits", 1, 0, "Ohm" },
        { "ogip", 1, 0, "ohm" },
        { "cds", 1, 0, "Ohm" },} },
    { "pc", "parsec", "length", "3.0857e16 m", NULL, {
        { "fits", 1, 0, "pc" },
        { "ogip", 1, 0, "pc" },
        { "cds", 1, 0, "pc" },} },
    { "ph", "photon", "events", NULL, NULL, {
        { "fits", 0, 0, "photon" },
        { "ogip", 0, 0, "photon" },
        { NULL, 0, 0, NULL },} },
    { "photon", "photon", "events", NULL, NULL, {
        { "fits", 0, 0, "photon" },
        { "ogip", 0, 0, "photon" },
        { NULL, 0, 0, NULL },} },
    { "pix", "(image/detector) pixel", "area", NULL, NULL, {
        { "fits", 0, 0, "pixel" },
        { "ogip", 0, 0, "pixel" },
        { "cds", 0, 0, "pix" },} },
    { "pixel", "(image/detector) pixel", "area", NULL, NULL, {
        { "fits", 0, 0, "pixel" },
        { "ogip", 0, 0, "pixel" },
        { "cds", 0, 0, "pix" },} },
    { "rad", "radian", "plane angle", NULL, NULL, {
        { "fits", 1, 0, "rad" },
        { "ogip", 1, 0, "rad" },
        { "cds", 1, 0, "rad" },} },
    { "s", "second", "time", NULL, NULL, {
        { "fits", 1, 0, "s" },
        { "ogip", 1, 0, "s" },
        { "cds", 1, 0, "s" },} },
    { "solLum", "solar luminosity", "luminosity", "3.8268e26 W", "L\\solar", {
        { "fits", 0, 0, "solLum" },
        { NULL, 0, 0, NULL },
        { "cds", 0, 0, "solLum" },} },
    { "solMass", "solar mass", "mass", "1.9891e30 kg", "M\\solar", {
        { "fits", 0, 0, "solMass" },
        { NULL, 0, 0, NULL },
        { "cds", 0, 0, "solMass" },} },
    { "solRad", "solar radius", "length", "6.9599e8 m", "R\\solar", {
        { "fits", 0, 0, "solRad" },
        { NULL, 0, 0, NULL },
        { "cds", 0, 0, "solRad" },} },
    { "sr", "steradian", "solid angle", NULL, NULL, {
        { "fits", 1, 0, "sr" },
        { "ogip", 1, 0, "sr" },
        { "cds", 1, 0, "sr" },} },
    { "u", "unified atomic mass unit", "", "1.6605387e-27 kg", NULL, {
        { "fits", 0, 0, "u" },
        { NULL, 0, 0, NULL },
        { NULL, 0, 0, NULL },} },
    { "voxel", "3-d analogue of pixel", "miscellaneous units", NULL, NULL, {
        { "fits", 0, 0, "voxel" },
        { "ogip", 0, 0, "voxel" },
        { NULL, 0, 0, NULL },} },
    { "yr", "year (Julian)", "time", "31 557 600s (365.25d), peta a (Pa) forbidden", NULL, {
        { "fits", 1, 0, "yr" },
        { "ogip", 0, 0, "yr" },
        { "cds", 1, 0, "yr" },} },
};
static int unit_defs_length = sizeof(unit_defs)/sizeof(unit_defs[0]);
