package uk.me.nxg.unity;


/**
 * Provides a mapping from unit abbreviations to unit definitions.
 * <p>This is a singleton class, so clients must first obtain the
 * instance of the class using {@link #getInstance}.
 */
public class UnitDefinitionMap implements java.io.Serializable {
    private static final long serialVersionUID =  44L;

    /**
     * The per-instance mapping of unit abbreviations to definitions
     */
    private java.util.Map<String,UnitDefinition> unitMap = null;

    /**
     * The singleton instance of this class.
     */
    private static UnitDefinitionMap singletonMap = null;

    /**
     * Constructs a new unit-definition map.  This is private on
     * purpose -- instances should be retrieved using the
     * {@link #getInstance} method.
     */
    private UnitDefinitionMap() {
        unitMap = new java.util.HashMap<String,UnitDefinition>();
    }

    /**
     * Persist a mapping of unit abbreviations to unit definitions.
     * The mapping is written to a Java serialization file, from which
     * it may subsequently be re-read by an instance of this class.
     *
     * <p>This method is public, but is not not expected to be used by
     * clients; it is used only when building this package.
     * FIXME: this is a poor design, and should be fixed when possible.
     */
    public static void persist(java.util.Map<String,UnitDefinition> m, java.io.File persistenceFile)
            throws java.io.IOException {
        // This is used by the program .../src/grammar/tools/ParseUnits.java.
        java.io.ObjectOutputStream oos
                = new java.io.ObjectOutputStream(new java.io.FileOutputStream(persistenceFile));
        UnitDefinitionMap newMap = new UnitDefinitionMap();
        newMap.unitMap.putAll(m);
        oos.writeObject(newMap);
        oos.close();
        // System.err.println("defs written to " + persistenceFile);
        // for (String uname : new java.util.TreeSet<String>(m.keySet())) {
        //     UnitDefinition u = m.get(uname);
        //     System.out.print(u.name() + ": ");
        //     String[] stxNames = { UnitParser.FITS, UnitParser.OGIP, UnitParser.CDS };
        //     for (String stxName : stxNames) {
        //         UnitDefinition.Syntax stx = u.getSyntax(stxName);
        //         if (stx != null) {
        //             System.out.print(stx + ";  ");
        //         }
        //     }
        //     System.out.println();
        // }

        return;
    }

    /**
     * Obtain an instance of the unit-definition map.
     */
    public static UnitDefinitionMap getInstance() {
        /*
         * This comes from a serialization file, which was written by
         * (typically) grammar/tools/ParseUnits
         * We get a java.io.IOException if the serialization stream
         * cannot be read, and a java.lang.ClassNotFoundException if
         * this present class does not exist (this shouldn't happen!).
         */
        if (singletonMap == null) {
            String resourceName = "uk/me/nxg/unity/known-units-serialized";
            try {
                java.io.InputStream is = ClassLoader.getSystemResourceAsStream(resourceName);
                assert is != null; // this should be guaranteed by the build process

                java.io.ObjectInputStream ois = new java.io.ObjectInputStream(is);
                @SuppressWarnings("unchecked")
                UnitDefinitionMap m = (UnitDefinitionMap)ois.readObject();
                ois.close();
                singletonMap = m;
                // System.out.println("defs read from " + resourceName);
                // for (String name : new java.util.TreeSet<String>(singletonMap.unitMap.keySet())) {
                //     UnitDefinition u = singletonMap.unitMap.get(name);
                //     System.out.print(u.name() + ": ");
                //     String[] stxNames = { UnitParser.FITS, UnitParser.OGIP, UnitParser.CDS };
                //     for (String stxName : stxNames) {
                //         UnitDefinition.Syntax stx = u.getSyntax(stxName);
                //         if (stx != null) {
                //             System.out.print(stx + ";  ");
                //         }
                //     }
                //     System.out.println();
                // }
            } catch (java.io.IOException e) {
                System.err.println("Can't find resource " + resourceName + " (" + e + ")");
            } catch (java.lang.ClassNotFoundException e) {
                System.err.println("Can't deserialize unit information: " + e);
            }
        }
        assert singletonMap != null;
        assert singletonMap.unitMap != null;
        return singletonMap;
    }

    /**
     * Looks up the unit which corresponds to a unit abbreviation
     */
    public UnitDefinition lookup(String k) 
    {
        return unitMap.get(k);
    }

    /**
     * Obtains all of the unit abbreviations known to this map.
     */
    public java.util.Set<String> keySet() {
        return unitMap.keySet();
    }
}
