package uk.me.nxg.unity;

/**
 * An abstract class which writes out unit expressions in the style
 * appropriate for a given syntax.
 *
 * <p>Instances of this class are created by {@link SyntaxFactory},
 * and are used via {@link UnitExpr#toFormattedString}.
 */
abstract class UnitWriter {
    protected UnitExpr ue;

    private java.text.NumberFormat nf;

    UnitWriter(UnitExpr ue) {
        this.ue = ue;
        nf = java.text.NumberFormat.getInstance(java.util.Locale.US);
    }

    /**
     * Write a number to a StringBuilder, avoiding any fractional parts if they're zero.
     */
    protected void writeNumber(StringBuilder sb,
                                      double d,
                                      boolean bracketsFloat,
                                      boolean bracketsNegative) {
        String numToWrite;
        boolean isRound;

        if (d == Math.floor(d)) { // no fractional part
            //numToWrite = Long.toString((Math.round(d)));
            numToWrite = nf.format(Math.round(d));
            isRound = true;
        } else {
            //numToWrite = Double.toString(d);
            numToWrite = nf.format(d);
            isRound = false;
        }
        boolean withBrackets = (bracketsFloat && !isRound) || (bracketsNegative && d<0.0);
        if (withBrackets) {
            sb.append('(').append(numToWrite).append(')');
        } else {
            sb.append(numToWrite);
        }
        return;
    }

    /**
     * Set the locale to be used for formatting numbers.
     */
    public void setLocale(java.util.Locale newLocale) {
        nf = java.text.NumberFormat.getInstance(newLocale);
    }

    abstract String write();
}
